@@ -2,7 +2,7 @@
 from __future__ import annotations
 
 from cmath import phase, polar, rect
-from collections.abc import Iterator
+from collections.abc import Iterator, Sequence
 from typing import Literal, NoReturn, overload
 
 __all__ = ["Vector"]
@@ -11,7 +11,7 @@ __all__ = ["Vector"]
 _object_setattr = object.__setattr__
 
 
-class Vector:
+class Vector(Sequence[float]):
     """A two-dimensional vector."""
 
     __slots__ = ("_complex",)
@@ -112,8 +112,16 @@ class Vector:
     def __len__(self, /) -> Literal[2]:
         return 2
 
+    @overload
     def __getitem__(self, key: int, /) -> float:
-        return self.rec()[key]
+        ...
+
+    @overload
+    def __getitem__(self, key: slice, /) -> tuple[float, ...]:
+        ...
+
+    def __getitem__(self, key, /):
+        return (self._complex.real, self._complex.imag)[key]
 
     def __iter__(self, /) -> Iterator[float]:
         yield self._complex.real
@@ -123,6 +131,15 @@ class Vector:
         yield self._complex.imag
         yield self._complex.real
 
+    def __contains__(self, item: object, /) -> bool:
+        return item == self._complex.real or item == self._complex.imag
+
+    def index(self, value: object, start: int = 0, stop: int = 2, /) -> int:
+        return (self._complex.real, self._complex.imag).index(value, start, stop)
+
+    def count(self, value: object, /) -> int:
+        return (self._complex.real, self._complex.imag).count(value)
+
     def __neg__(self, /) -> Vector:
         return _from_complex(-self._complex)
 
@@ -143,6 +160,12 @@ class Vector:
     def __abs__(self, /) -> float:
         return abs(self._complex)
 
+    def __copy__(self, /) -> Vector:
+        return self
+
+    def __deepcopy__(self, _, /) -> Vector:
+        return self
+
     @property
     def x(self) -> float:
         """The horizontal component of the vector."""
